@@ -183,7 +183,7 @@ boolean checking_bayesallfile(world_fmt *world, option_fmt *options, data_fmt *d
 {
   boolean done=FALSE;
   boolean recover_needed = FALSE;
-  long step, locus, replicate;
+  long locus, replicate;
   char * input = (char *) mycalloc(SUPERLINESIZE, sizeof(char));
   char *inptr = input;
   //FILE * mdimfile = fopen(options->bayesmdimfilename,"r");
