@@ -40,7 +40,7 @@
 * 
 */
 /* $Id: main.c 2169 2013-08-24 19:02:04Z beerli $*/
-
+#include <sys/resource.h>
 #include "migration.h"
 //#include "aic.h"
 #include "assignment.h"
@@ -105,6 +105,7 @@ dispatch_semaphore_t semaphore;
 #define SUN    universe[3]	/*!< fourth coldest chain                             */
 
 /* GLOBAL VARIABLES +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
+extern time_t startseconds; 
 extern int simulator;
 extern int myID;	  /*!< myID=0 for single-cpu program and master in MPI program, worker nodes myID > 0 */
 extern int myRepID;	  /*!< myID=0 for single-cpu program and master in MPI program, worker nodes myID > 0 */
@@ -116,6 +117,8 @@ extern int use_beagle_gpu;
 extern int use_beagle_dynamicscale;
 extern int use_beagle_autoscale;
 extern int use_beagle_manualscale;
+
+time_t startseconds;
 int simulator;
 int myID;	  /*!< myID=0 for single-cpu program and master in MPI program, worker nodes myID > 0 */
 int myRepID;	  /*!< myID=0 for single-cpu program and master in MPI program, worker nodes myID > 0 */
@@ -201,9 +204,9 @@ extern   pdf_contents canvas;
 extern   int page_counter;
 extern   char pdf_pagetitle[LINESIZE+1];
 extern   char pdf_time[LINESIZE+1];
-extern   float page_height;
-extern   float left_margin;
-extern   float page_width;
+extern   double page_height;
+extern   double left_margin;
+extern   double page_width;
 
 
 int
@@ -423,6 +426,27 @@ main (int argc, char **argv)
 #endif
 #endif
 
+    //---------------------------------------------------------------------------------------------
+    // set stacksize                                                                                                          
+    const rlim_t kStackSize = MIN_STACKSIZE_16MB ;
+    struct rlimit rl;
+    int result;
+
+    result = getrlimit(RLIMIT_STACK, &rl);
+    if (result == 0)
+      {
+        if (rl.rlim_cur < kStackSize)
+          {
+            rl.rlim_cur = kStackSize;
+            result = setrlimit(RLIMIT_STACK, &rl);
+            if (result != 0)
+              {
+                fprintf(stderr, "setrlimit returned result = %d\n", result);
+              }
+          }
+      }
+
+
     //---------------------------------------------------------------------------------------------
     // MPI initialisation
 #ifdef MPI
@@ -502,7 +526,7 @@ main (int argc, char **argv)
 #endif
 	read_options_master (options);
 	options->menu = set_usemenu(usemenu, options->menu);
-	print_menu_title (stdout, options);
+	print_menu_title (stdout, options, EARTH);
 	get_menu (options, EARTH, data);
 	//check_bayes_options(options);
 #ifdef MPI        
@@ -537,7 +561,7 @@ main (int argc, char **argv)
 
     if (options->writelog && myID == MASTER)
       {
-        print_menu_title (options->logfile, options);
+        print_menu_title (options->logfile, options, EARTH);
       }
     
     EARTH->repkind = SINGLECHAIN;
@@ -1334,15 +1358,15 @@ print_heating_progress2 (FILE * file, worldoption_fmt * options,
   get_time (nowstr, "%H:%M:%S");
   plog = (char *) mycalloc(LONGLINESIZE,sizeof(char));
 #ifdef MPI
-  plogsize = sprintf(plog, "[%3i] %s   %li chains: ", myID, nowstr, options->heated_chains);
+  plogsize = sprintf(plog, "[%3i] %s   Sampling Temp[%li]:", myID, nowstr, options->heated_chains);
 #else
-  plogsize = sprintf(plog, "%s   %li chains: ", nowstr, options->heated_chains);
+  plogsize = sprintf(plog, "%s   Sampling Temp[%li]: ", nowstr, options->heated_chains);
 #endif
   if (options->heated_chains > 4)
     strcpy(dots,",...");
   else
     dots[0]='\0';
-  plogsize += sprintf (plog + plogsize, "Temp(%.4g,%.4g,%.4g,%.4g%s) ",universe[0]->averageheat,
+  plogsize += sprintf (plog + plogsize, "(%.4g,%.4g,%.4g,%.4g%s) ",universe[0]->averageheat,
 		       universe[1]->averageheat,universe[2]->averageheat,universe[3]->averageheat,dots);
   plogsize += sprintf (plog + plogsize, "Acc(%.2f,%.2f,%.2f,%.2f%s) ",universe[0]->accept_freq,
 		       universe[1]->accept_freq,universe[2]->accept_freq,universe[3]->accept_freq,dots);
@@ -1443,10 +1467,11 @@ setup_locus (long locus, world_fmt * world, option_fmt * options,
 {
   world->locus = locus;
   set_param (world, data, options, locus);
-  if (world->options->progress)
-    print_menu_locus (stdout, world, locus);
-  if (world->options->writelog)
-    print_menu_locus (world->options->logfile, world, locus);
+  // replaced with more informative reporting in burnin_bayes(). 
+  //if (world->options->progress)
+  //  print_menu_locus (stdout, world, locus);
+  //if (world->options->writelog)
+  //  print_menu_locus (world->options->logfile, world, locus);
   world->start = TRUE;
 #ifdef NEWVERSION
   if(options->has_unassigned && locus>0)
@@ -1486,7 +1511,6 @@ setup_locus (long locus, world_fmt * world, option_fmt * options,
 #endif
   if (data->skiploci[locus])	/* skip loci with no tips */
     return 0;
-
   create_treetimelist (world, &world->treetimes);
   fix_times (world, options);
 #ifdef DEBUG
@@ -2090,9 +2114,9 @@ void run_chains (world_fmt ** universe,
     }
   get_time (nowstr, "%H:%M:%S");
 #ifdef MPI
-  FPRINTF(stdout,"[%3i] %8.8s   Sampling ...\n",myID, nowstr);
+  FPRINTF(stdout,"[%3i] %8.8s   Sampling of %li steps (Locus: %li/%li, Replicate: %li/%li) \n",myID, nowstr, steps*increment, 1+EARTH->locus, EARTH->loci, 1+EARTH->rep, EARTH->maxreplicate);
 #else
-  FPRINTF(stdout,"%8.8s   Sampling ...\n", nowstr);
+  FPRINTF(stdout,"%8.8s   Sampling of %li steps (Locus: %li/%li, Replicate: %li/%li) \n", nowstr, steps*increment, 1+EARTH->locus, EARTH->loci, 1+EARTH->rep, EARTH->maxreplicate);
 #endif      
   run_steps (universe, usize, options, localheating_pool,
 	     increment, steps, rep);
@@ -2169,6 +2193,11 @@ run_replicate (long locus,
       }
     /* short and long chains ----------------------------- */
     set_bounds (&increment, &oldsteps, &chains, options, type);
+	//trying to find problem with parallel programming and bayesallfile
+    //fprintf(stdout,"%i> PROBLEM heat=%f custm=%s custm2=%s\n",myID, EARTH->heat, EARTH->options->custm, EARTH->options->custm2);
+    //exit(-1);
+
+
     EARTH->increment = increment;
     while (runs-- >= 0)
     {
@@ -2293,7 +2322,7 @@ MYREAL combine_scaling_factor(world_fmt *world)
 	      pr = scaling_prior(world,i,v);
 	      scaling_factor += (1.0-world->loci) * (log(w) + pr);
 #ifdef DEBUG
-	      printf("%i> scaling factor with 'c': %li  %li k=%f log(w)=%f  w=%f v=%f pr=%f  [%f]\n",myID, i, pop, scaling_factor, log(w), w, v, pr, world->param0[i]);
+	      printf("%i> scaling factor with 'c': %li k=%f log(w)=%f  w=%f v=%f pr=%f  [%f]\n",myID, i, scaling_factor, log(w), w, v, pr, world->param0[i]);
 #endif
 
 	    }
@@ -2414,32 +2443,22 @@ void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
   fprintf(file,"--------------------------------------------------------------------\n[Use this value for Bayes factor calculations:\nBF = Exp[log(P(D|thisModel) - log(P(D|otherModel)]\nshows the support for thisModel]\n\n");
   if(file==EARTH->outfile)
     pdf_bayes_factor_header(EARTH,options);
+  fprintf(file,"\n\nLocus      Raw Thermodynamic score(1a)  Bezier approximated score(1b)     %s\n"," Harmonic mean(2)");
+  fprintf(file,"------------------------------------------------------------------------------------------\n");
+
   if(EARTH->loci>1)
     {
-      //      fprintf(file,"\n\nLocus      Raw Thermodynamic score(1a)  Bezier approximated score(1b)     %s\n",options->heating ?  "Stepstone score(2)" : " Harmonic mean(2)");
-      fprintf(file,"\n\nLocus      Raw Thermodynamic score(1a)  Bezier approximated score(1b)     %s\n"," Harmonic mean(2)");
-      fprintf(file,"------------------------------------------------------------------------------------------\n");
       if(file==EARTH->outfile)
 	pdf_bayes_factor_rawscores_header(EARTH,options);
     }
+
   if(options->heating)//-----------------------heating
     {
-#ifdef DEBUG
-      //for(locus=0;locus<EARTH->loci;locus++)
-      //{
-      //  printf("%i> BF(%li)[%f] ",myID, locus, locusweight[locus]);
-      //  for(t=0; t < hc; t++)                    
-      //    printf("%f ",EARTH->bf[locus * hc + t]);                  
-      //  printf("\n");    	  
-      //}
-#endif
-      //hsum = 0.0;
       for(locus=0;locus<EARTH->loci;locus++)
 	{
 	  if(EARTH->data->skiploci[locus])
 	    continue;
 
-	  //ratio = 0;
 	  lsum = 0.;
 	  lsum0 = 0.;
 	  // from very hot to cold, the 
@@ -2462,8 +2481,6 @@ void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
 		    {
 		      heat0 = 1./options->heat[t-1];
 		      heat1 = 1./options->heat[t];
-		      //heat0 = universe[t-1]->heat ;
-		      //heat1 = universe[t]->heat;
 		    }
 		}
 	      else
@@ -2517,6 +2534,8 @@ void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
 	  bfsum2 += approxlsum + lsum - lsum0;  	  
 	  bfsum += lsum; //+ EARTH->bfscale[locus];
 	}
+      // print out "ALL" row for both multiloci and single loci run (the single locus run has the same
+      // form as the multilocus run so that I can grep the results more easily for model comparison
       if(EARTH->loci>1)
 	{
 	  scaling_factor = combine_scaling_factor(EARTH);
@@ -2524,18 +2543,15 @@ void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
 
 	  bfsum2 += scaling_factor;
 	  hsum   += scaling_factor;
+
 	  fprintf(file,"---------------------------------------------------------------------------------------\n");
-	  fprintf(file,"  All  %22.2f        %22.2f           %12.2f\n[Scaling factor = %f]\n", bfsum, bfsum2, hsum, scaling_factor); 
 	  if(file==EARTH->outfile)
 	    pdf_bayes_factor_rawscores(-1L, bfsum, bfsum2, hsum);
 	}
-      else 
-	{
-	  fprintf(file,"\n\n(1a) Thermodynamic integration: log(Prob(D|Model))=%f (%f with Bezier-approximation[1b]) %s\n", bfsum, bfsum2,  
-		  options->adaptiveheat!=NOTADAPTIVE ? "(adaptive heating -> value may most likely be wrong)" : "");
-	  fprintf(file,"(2) Harmonic mean:             log(Prob(D|Model))=%f\n",hsum);
-	  fprintf(file,"(1) and (2) should give a similar result, in principle.\nBut (2) is overestimating the likelihood, it and is presented for historical reasons and should not be used. But (1) needs heating with chains that span a temperature range of 1.0 to at least 100,000.\n\n");
-	}
+      fprintf(file,"  All  %22.2f        %22.2f           %12.2f\n[Scaling factor = %f]\n", bfsum, bfsum2, hsum, scaling_factor); 
+      fprintf(file,"\n\n(1a) Thermodynamic integration: log(Prob(D|Model)): Good approximation with many temperatures\n");
+      fprintf(file,"(1b) Bezier-approximated Thermodynamic integration: when using few temperatures USE THIS!\n");
+      fprintf(file,"(2)  Harmonic mean approximation: Overestimates the marginal likelihood, poor variance\n\n");
     }
   else   // -----------------------------------------not heating
     {
@@ -2555,18 +2571,13 @@ void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
 	  scaling_factor = combine_scaling_factor(EARTH);
 	  hsum += scaling_factor;
 	  fprintf(file,"---------------------------------------------------------------------------------------\n");
-	  fprintf(file,"      All           ------                           ------            %12.2f\n", hsum); 
 	  if(file==EARTH->outfile)
-	    pdf_bayes_factor_rawscores_harmo(-1L, hsum);
-	}
-      else
-	{
-	  fprintf(file,"\n\n(1) Thermodynamic integration: log(Prob(D|Model))= UNAVAILABLE because no heating was used\n");
-	  fprintf(file,"(2) Harmonic mean:             log(Prob(D|Model))=%f\n",hsum);
-	  fprintf(file,"(1) is giving good results whereas (2) is overestimating the likelihood,\
-(2) is presented for historical reasons and should not be used. But (1) needs heating with chains that span a temperature rang\
-e of 1.0 to at least 100,000.\n\n");
+	    pdf_bayes_factor_rawscores_harmo(-1L, hsum);	
 	}
+      fprintf(file,"      All           ------                           ------            %12.2f\n", hsum); 
+      fprintf(file,"\n\n(2) Harmonic mean approximation: Overestimates the marginal likelihood, poor variance\n\n");
+      fprintf(file,"If you want to compare models, USE HEATING to calculate the marginal likelihoods\n");
+      fprintf(file,"the harmonic mean estimator is poorly estimating the marginal likelihood!]");
     }
   if(file==EARTH->outfile)
     {
@@ -2644,13 +2655,13 @@ void calculate_BF(world_fmt **universe, option_fmt *options)
   long hc = options->heated_chains;
   if(EARTH->data->skiploci[locus])
     return;
-  if(EARTH->likelihood[EARTH->G] <= -HUGE)
+  if(EARTH->likelihood[EARTH->G] <= (double) -HUGE)
     return;
   //am contains the counter
   EARTH->am[locus] += 1;
   //locus = EARTH->locus;
   xx = EARTH->likelihood[EARTH->G];
-  if(xx <= -HUGE)
+  if(xx <= (double) -HUGE)
     {
       warning("%i> l=%li likelihood < -HUGE", myID, locus);
       return;
@@ -2676,7 +2687,7 @@ void calculate_BF(world_fmt **universe, option_fmt *options)
       for (i = 0; i < hc; i++)
 	{
 	  xx = universe[i]->likelihood[universe[i]->G];
-	  if (EARTH->am[locus] > 0.0 || xx > -HUGE)
+	  if (EARTH->am[locus] > 0.0 || xx > (double) -HUGE)
 	    EARTH->bf[locus * hc + i] += (xx - EARTH->bf[locus * hc + i])/ (EARTH->am[locus]);
 	  else
 	    {
