@@ -1130,7 +1130,7 @@ void finish_mutationmodel(world_fmt *world, data_fmt *data, option_fmt *options,
 	  adjust_mutationmodel(s,options); // incase there is no infile definition then set options 
 	  set_subloci_basefrequencies(s,world, options, data, locus, z); 
 #ifdef DEBUG
-	  printf("2@@@@@@@@@@@@@@@@@@@@@@@ %i> %p %i: 0:%f 1:%f 2:%f \n",myID, s, s->model, s->parameters[0],s->parameters[1],s->parameters[2]);
+	  printf("2@@@@@@@@@@@@@@@@@@@@@@@ %i> %p %i: 0:%f 1:%f 2:%f \n",myID, (void *) s, s->model, s->parameters[0],s->parameters[1],s->parameters[2]);
 #endif	      
 
 	  set_mutationmodel_eigenmaterial(z,world); //eigenvectormatrix, inverse eigenvector matrix, eigenvalues
@@ -1236,9 +1236,9 @@ void print_mutationrate_weights(FILE *file, MYREAL *murates, long *segregs, MYRE
   long locus;
   //  char ***buffer;
   //long rows = loci+2;
-  float mumean=0.0;
-  float segregmean=0.0;
-  float wamean=0.0;
+  double mumean=0.0;
+  double segregmean=0.0;
+  double wamean=0.0;
   fprintf(file,"Relative mutation rate among loci estimated from the data \n");
   fprintf(file,"==========================================================\n");
   if(wattersons==NULL)
@@ -1249,7 +1249,7 @@ void print_mutationrate_weights(FILE *file, MYREAL *murates, long *segregs, MYRE
       for (locus=0; locus < loci; locus++)
 	{
 	  fprintf(file,"%5li          % 5.5f         % 6li\n",locus+1, murates[locus], segregs[locus]);
-	  mumean += (float) (murates[locus] - mumean)/(locus+1);
+	  mumean += (murates[locus] - mumean)/(locus+1);
 	  segregmean += (segregs[locus] - segregmean)/(locus+1);
 	}
       fprintf(file,"%5s          % 5.5f         % 6.1f\n","All", mumean, segregmean);
@@ -1262,8 +1262,8 @@ void print_mutationrate_weights(FILE *file, MYREAL *murates, long *segregs, MYRE
       for (locus=0; locus < loci; locus++)
 	{
 	  fprintf(file,"%5li          % 5.5f         %2.8f      % 6li\n",locus+1, murates[locus], wattersons[locus], segregs[locus]);	
-	  mumean += (float) (murates[locus] - mumean)/(locus+1);
-	  wamean += (float) (wattersons[locus] - wamean)/(locus+1);
+	  mumean +=  (murates[locus] - mumean)/(locus+1);
+	  wamean +=  (wattersons[locus] - wamean)/(locus+1);
 	  segregmean += (segregs[locus] - segregmean)/(locus+1);
 	}
       fprintf(file,"%5s          % 5.5f         %2.8f      % 6.1f\n","All", mumean, wamean, segregmean);	
